#!/usr/bin/env python
# coding: utf-8

"""
16.3 딥러닝 모델의 성능
<1> 유효성 데이터로 그래프 그리기
p.339 ~ p.344
"""

# In[1]: p.341
import matplotlib.pyplot as plt
from sklearn.datasets import make_blobs
data, labels = make_blobs(n_samples=10000, n_features=2, centers=2, random_state=0)
plt.scatter(data[:,0], data[:,1], c=labels)
plt.show()


# In[2]: p.342
from sklearn.model_selection import train_test_split
X_train, X_test, y_train, y_test = train_test_split(data, labels, test_size=0.2)

X_val = X_train[:1000]
X_train = X_train[1000:]
y_val = y_train[:1000]
y_train = y_train[1000:]


# In[3]:
from keras import models
from keras import layers
model = models.Sequential()
model.add(layers.Dense(1, input_dim=2, activation='sigmoid'))


# In[4]:
model.summary()


# In[5]:
model.compile(optimizer='SGD', loss='binary_crossentropy', metrics=['accuracy'])


# In[6]: p.343
history = model.fit(X_train, y_train, epochs=10, batch_size=100, validation_data=(X_val, y_val))


# In[7]:
result = model.evaluate(X_test, y_test)
result


# In[8]:
import matplotlib.pyplot as plt
history_dict = history.history
loss = history_dict['loss']
val_loss = history_dict['val_loss']
epochs = range(1, len(loss)+1)
plt.plot(epochs, loss, 'bo', label='Training loss')
plt.plot(epochs, val_loss, 'b', label='validation loss')
plt.title('Training and validation loss')
plt.axis([0, 12, 0.0, 6.0])
plt.xlabel('Epochs')
plt.ylabel('Loss')
plt.legend()
plt.show()


# In[9]: p.344
plt.clf()
acc = history_dict['accuracy']
val_acc = history_dict['val_accuracy']
plt.plot(epochs, acc, 'bo', label='Training acc')
plt.plot(epochs, val_acc, 'b', label='Validation acc')
plt.title('Trainging and validation accuracy')
plt.xlabel('Epochs')
plt.ylabel('Accuracy')
plt.axis([0, 12, 0.7, 1.1])
plt.legend()
plt.show()

